[−][src]Struct gimli::read::AttributeSpecification
The description of an attribute in an abbreviated type. It is a pair of name and form.
Implementations
impl AttributeSpecification[src][−]
pub fn new(
name: DwAt,
form: DwForm,
implicit_const_value: Option<i64>
) -> AttributeSpecification[src][−]
name: DwAt,
form: DwForm,
implicit_const_value: Option<i64>
) -> AttributeSpecification
Construct a new AttributeSpecification from the given name and form
and implicit const value.
pub fn name(&self) -> DwAt[src][−]
Get the attribute's name.
pub fn form(&self) -> DwForm[src][−]
Get the attribute's form.
pub fn implicit_const_value(&self) -> i64[src][−]
Get the attribute's implicit const value.
pub fn size<R: Reader>(&self, header: &UnitHeader<R>) -> Option<usize>[src][−]
Return the size of the attribute, in bytes.
Note that because some attributes are variably sized, the size cannot
always be known without parsing, in which case we return None.